from typing_extensions import final


@final
class ARC4(object):
    def __init__(self, key: bytes) -> None: ...
    def encrypt(self, data: bytes) -> bytes: ...
    def decrypt(self, data: bytes) -> bytes: ...
